Properties Methods Events Direct Link

# Class Ext.ux.FieldReplicator

Package: | Ext.ux
Defined In: | FieldReplicator.js
Class: | FieldReplicator
Extends: | Object

A plugin for Field Components which creates clones of the Field for as long as the user keeps filling them. Leaving the final one blank ends the repeating series.

Usage:

    {
            xtype: 'combo',
            plugins: [ Ext.ux.FieldReplicator ],
            triggerAction: 'all',
            fieldLabel: 'Select recipient',
            store: recipientStore
        }

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.